/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: LoaderManager.java 241 2006-04-19 13:16:21Z alouis $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.classloader;

import java.net.URL;
import java.net.URLClassLoader;
import java.util.List;

import org.objectweb.petals.PetalsException;

/**
 * 
 * @version $Rev: 241 $ $Date: 2006-04-19 13:16:21Z $
 * @since	Petals 1.0
 * @author	Adrien LOUIS, <a href="mailto:rmarins@fossilec.com">Rafael Marins</a>
 */
public interface LoaderManager {
	
	
	/**
	 * Must not return null.
	 * @param baseUrls
	 * @param classpathUrls
	 * @param useParentFirst
	 * @return
	 * @throws PetalsException
	 */
	public URLClassLoader createClassLoader(URL[] baseUrls, List<String> classpathUrls, boolean useParentFirst)
	throws PetalsException;
	
/**
 * 
 * @param classLoaderId
 * @param baseUrls
 * @param classpathUrls
 * @param useParentFirst
 * @param sharedLibrariesNameList
 * @return
 * @throws PetalsException
 */	
	public URLClassLoader createComponentClassLoader(String classLoaderId, URL[] baseUrls, List<String> classpathUrls,
            boolean useParentFirst, List<String> sharedLibrariesNameList) throws PetalsException;

	
	/**
	 * Create a classloader for a sharedLibrary.
	 * This classLoader will be added to the SharedLibrariesClassLoader.
	 * @param baseUrls
	 * @param classpathUrls
	 * @param useParentFirst
	 * @return
	 * @throws PetalsException
	 */
	public URLClassLoader createSharedLibrariesClassLoader(String classLoaderId, URL[] baseUrls, List<String> classpathUrls,
			boolean useParentFirst) throws PetalsException; 
	
	public boolean containsClassLoader(String classLoaderId);
	
	/** 
	 * Remove the classLoader from the list.
	 * If the classLoader is a ClassLoader for sharedLibraries,
	 * remove it from the SharedLibrariesClassLoader
	 */
	public void deleteClassLoader(String classLoaderId);
}
