/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: Loaders.java 233 2006-04-18 16:10:51Z alouis $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.classloader;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 
 * @version	$Revision: 233 $ $Date: 2006-04-18 16:10:51Z $
 * @since	Petals 1.0
 * @author	<a href="mailto:rmarins@fossilec.com">Rafael Marins</a>
 */
class Loaders {

	public static final String COMMON_LOADER = "common";

	private static Loaders singletonInstance;

	private static SharedLibrariesClassLoader slClassLoader;
	
	private Map<String,PetalsClassLoader> classLoadersTable =
		new HashMap<String,PetalsClassLoader>();

	/**
	 * Constructor.
	 * An unique SharedLibrariesClassLoader is created. 
	 * It must be used to reference all classloader created for shared libraries.
	 *
	 */
	private Loaders() {
		super();
		
		try {
			slClassLoader = new SharedLibrariesClassLoader();
		} catch (IOException e) {
			// TODO Auto-generated catch block
		}
	}

	public static Loaders getInstance() {
		if (singletonInstance == null) {
			singletonInstance = new Loaders();
		}
		return singletonInstance;
	}

	public boolean contains(String loaderName) {
		return classLoadersTable.containsKey(loaderName);
	}

	public PetalsClassLoader get(String loaderName) {
		return classLoadersTable.get(loaderName);
	}

	public ClassLoader put(String loaderName, PetalsClassLoader cl) {
		return classLoadersTable.put(loaderName, cl);
	}

	public void remove(String loaderName) {
		classLoadersTable.remove(loaderName);
	}
	
	public SharedLibrariesClassLoader getSharedLibrariesClassLoader()
	{
		return slClassLoader;
	}

//	/**
//	 * @return
//	 */
//	private static ClassLoader createCommonLoader() {
//
//		String basedir = SystemUtil.getPetalsInstallDirectory().getAbsolutePath();
//
//		ClassPath cp = new ClassPath();
//		cp.addPathElement(basedir + "/common", false, new String[] {".jar"});
//		cp.addPathElement(basedir + "/conf");
//		cp.addPathElement(basedir + "/conf/adl");
//
//		ClassLoader loader = new PetalsClassLoader(cp);
//
//		return loader;
//	}
}
