/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: RepositoryService.java 250 2006-04-21 12:20:57Z ofabre $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.repository;

import java.io.File;
import java.net.URI;

import org.objectweb.petals.PetalsException;

/**
 * Platform Component Repository.
 *
 * @version	$Rev: 250 $ $Date: 2006-04-21 12:20:57Z $
 * @since	Petals 1.0
 * @author	<a href="mailto:rmarins@fossilec.com">Rafael Marins</a>
 */
public interface RepositoryService {

	
	/**
	 * Verifies if the Repository contains a package with the
	 * specified identification. Returns <code>true</code> if that package
	 * exists. Otherwise, returns <code>false</code>.
	 *
	 * @param uuid this is the unique repository's identification for
	 * a given component.
	 * @return <code>boolean</code> contains or not a component with the given
	 * identification. 
	 */
	public boolean containsPackage(String uuid);

	/**
	 * 
	 * @param uuid <code>String</code> unique repository package identifier
	 * within the repository.
	 * @param location <code>URI</code> the Zip archive file to add flatten
	 * into the repository.
	 * @return <code>URI</code> installation root of package in the repository.
     * Must be a valid directory.
	 * @throws PetalsException
	 */
	public URI addPackage(String uuid, URI location) throws PetalsException;
	
	/**
	 * 
	 * @param suId <code>String</code> unique SU identifier
	 * within the repository.
	 * @param suZipLocation <code>URI</code> the SU Zip archive file to add flatten
	 * into the repository.
	 * @param saId <code>String</code> unique SA identifier
	 * within the repository where SU add to be flatten
	 * @return <code>URI</code> installation root of su in the repository.
     * Must be a valid directory.
	 * @throws PetalsException
	 */
	public URI explodeSUIntoSAInstallFolder(String suId, 
									URI suZipLocation, 
									String saId) throws PetalsException;

	/**
	 * Delete and clean all package repository related data for the given
	 * identification.
	 *
	 * @param componentId
	 * @return <code>true</code> for sucessful removal. Otherwise,
     * <code>false</code>.
	 */
	public boolean removePackage(String componentId);

	/**
	 * Return the root directory of this component 
	 * @param componentId
	 * @return
	 */
	public File getComponentRoot(String componentId);
	
	/**
	 * Return the install directory of the component 
	 * @param componentId
	 * @return
	 */
	public File getComponentInstallRoot(String componentId);

	/**
	 * Return the work directory of the component
	 * @param componentId
	 * @return
	 */
	public File getComponentWorkRoot(String componentId);

}
