/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: CollectionsUtil.java 74 2006-01-17 17:12:07Z rmarins $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.util;

import java.util.Enumeration;
import java.util.NoSuchElementException;

/**
 * @author Rafael Marins
 * @version $Rev: 74 $ $Date: 2006-01-17 17:12:07Z $
 */
public class CollectionsUtil {

	private static final class CompoundEnumeration implements Enumeration {

		private final Enumeration e1, e2;

		public CompoundEnumeration(Enumeration e1, Enumeration e2) {
			this.e1 = e1;
			this.e2 = e2;
		}

		public boolean hasMoreElements() {
			return e1.hasMoreElements() || e2.hasMoreElements();
		}

		public Object nextElement() throws NoSuchElementException {
			if (e1.hasMoreElements()) {
				return e1.nextElement();
			} else {
				return e2.nextElement();
			}
		}

	}

	public static Enumeration append(Enumeration e1, Enumeration e2) {
		return new CompoundEnumeration(e1, e2);
	}

}
